import sys
import numpy as np
import cv2

n = len( sys.argv )
if n != 2 :
	print( "Args: nombre_imagen_entrada" )
	sys.exit(1)

nombre = sys.argv[1]

Imagen1 = cv2.imread( nombre, cv2.IMREAD_GRAYSCALE )
rens, cols = np.shape( Imagen1 )
print( rens, cols )

# Le aplicamos un suavizamiento a la imagen de entrada
Imagen1 = cv2.GaussianBlur( Imagen1, (5,5), 0 )

# Binarizamos la imagen de entrada
# Todos los píxeles abajo de 127 son puestos a 0, los
# demás a 255
ret, Imagen1 = cv2.threshold( Imagen1, 127, 255, cv2.THRESH_BINARY )
ImagenBinaria = ~Imagen1

# Le quitamos ruido con dos erosiones
# Creamos el elemento estructural
element = cv2.getStructuringElement( cv2.MORPH_CROSS, (3, 3) )

# Aplicamos dos erosiones y dos dilataciones
Imagen2 = cv2.erode( ImagenBinaria, element, iterations = 2)
Imagen3 = cv2.dilate( ImagenBinaria, element, iterations = 2)

# morphologyEx(src, op, kernel[, dst[, anchor[, iterations[, borderType[, borderValue]]]]]) -> dst

cv2.imwrite( "binarizada.png", Imagen3 )

# Ya podemos extraer las formas de la imagen "Imagen3" 

num, Etiquetas = cv2.connectedComponents( Imagen3, 8 ) 

print( ret )
print( type(Etiquetas) )

Img = np.zeros( (rens, cols), dtype="uint8" )

i = 1
while i < num :
	# Voy a extraer cada forma de la imagen

	# Limpio la imagen de salida
	j = 0
	while j<rens :
		k = 0
		while k<cols :
			Img[j,k] = 0
			k +=1	
		j +=1	

	j = 0
	while j<rens :
		k = 0
		while k<cols :
			if Etiquetas[j,k] == i :
				Img[j,k] = 255
			k +=1	
		j +=1	

	# En Img está una forma
	minombre = str(i) + ".png"
	cv2.imwrite( minombre, Img )
	
	# Calculamos las características de la forma
	# serán los momentos de Hu

	moments = cv2.moments(Img) 
	# Calculate Hu Moments 
	huMoments = cv2.HuMoments(moments)
	print( i, huMoments[0], huMoments[1], huMoments[3], huMoments[4], huMoments[5], huMoments[6] )
	i += 1
